@@ -1,6 +1,6 @@
 r'''
 >>> gmpy.version()
-'1.0'
+'1.02'
 >>>
 '''
 
@@ -16,14 +16,16 @@ import gmpy_test_rnd
 import gmpy_test_mpf
 import gmpy_test_mpq
 import gmpy_test_mpz
+import gmpy_test_dec
 
 
 test_modules = (gmpy_test_cvr, gmpy_test_rnd, gmpy_test_mpf,
     gmpy_test_mpq, gmpy_test_mpz,
+    gmpy_test_dec,
     )
 
 _g = gmpy
-print "Unit tests for gmpy 1.01 release candidate"
+print "Unit tests for gmpy 1.02 release candidate"
 print "    on Python", sys.version
 print "Testing gmpy %s (GMP %s), default caching (%s, %s, %s..%s)" % (
     (_g.version(), _g.gmp_version(), _g.get_zcache(), _g.get_qcache(),
@@ -31,8 +33,10 @@ print "Testing gmpy %s (GMP %s), default caching (%s, %s, %s..%s)" % (
 
 pf, pt = 0, 0
 for x in test_modules:
+    testit = x._test()
+    failures, tests = testit
+    if tests == 0: continue
     print x.__name__,
-    failures, tests = x._test()
     print "%3d tests, %d failures" % (tests-pt, failures-pf)
     pf, pt = failures, tests
 
